==> blesta-5.10.2.zip: blesta/plugins/order/language/ru_ru/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Электронная почта для восстановления (необязательно)';
$lang['Signup.!error.email.blacklist'] = 'Ваш заказ не может быть обработан в данный момент.';
$lang['Signup.index.signup_btn'] = 'Создать учетную запись';
$lang['Signup.index.continue_btn'] = 'Продолжить оформление заказа';
$lang['Signup.index.login_btn'] = 'Войти';
$lang['Signup.index.field_receive_email_marketing'] = 'Я хочу получать электронные сообщения о новых продуктах, услугах и предложениях.';
$lang['Signup.index.field_confirmpassword'] = 'Подтвердите пароль';
$lang['Signup.index.field_newpassword'] = 'Пароль';
$lang['Signup.index.field_password'] = 'Пароль';
$lang['Signup.index.field_username'] = 'Имя пользователя';
$lang['Signup.index.field_action_signup'] = 'Создать учетную запись';
$lang['Signup.index.field_action_login'] = 'Войти';
$lang['Signup.index.field_action_continue'] = 'Продолжить как %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Укажите имя пользователя';
$lang['Signup.index.field_username_type_email'] = 'Используйте электронную почту в качестве имени пользователя';
$lang['Signup.index.field_email'] = 'Электронная почта';
$lang['Signup.index.field_fax'] = 'Факс';
$lang['Signup.index.field_phone'] = 'Телефон';
$lang['Signup.index.field_title'] = 'Название';
$lang['Signup.index.field_country'] = 'Страна';
$lang['Signup.index.field_zip'] = 'Почтовый индекс';
$lang['Signup.index.field_state'] = 'Штат/провинция';
$lang['Signup.index.field_city'] = 'Город';
$lang['Signup.index.field_address2'] = 'Адрес 2';
$lang['Signup.index.field_address1'] = 'Адрес 1';
$lang['Signup.index.field_company'] = 'Компания/организация.';
$lang['Signup.index.field_lastname'] = 'Фамилия';
$lang['Signup.index.field_firstname'] = 'Имя';
$lang['Signup.index.field_taxid'] = 'ИНН/ВАТИН';
$lang['Signup.!notice.email_verification'] = 'Было отправлено сообщение для проверки вашего адреса электронной почты. Пожалуйста, завершите проверку при первой же возможности.';
$lang['Signup.!notice.force_email_usernames'] = 'Ваше имя пользователя будет совпадать с вашим адресом электронной почты.';
$lang['Signup.!error.not_client_owner'] = 'Чтобы продолжить, вы должны войти в систему как владелец клиента.';
$lang['Signup.!error.captcha.invalid'] = 'Введенная капча недействительна. Пожалуйста, попробуйте еще раз.';

==> blesta-5.11.4.zip: blesta/plugins/order/language/ru_ru/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Электронная почта для восстановления (необязательно)';
$lang['Signup.!error.email.blacklist'] = 'Ваш заказ не может быть обработан в данный момент.';
$lang['Signup.index.signup_btn'] = 'Создать учетную запись';
$lang['Signup.index.continue_btn'] = 'Продолжить оформление заказа';
$lang['Signup.index.login_btn'] = 'Войти';
$lang['Signup.index.field_receive_email_marketing'] = 'Я хочу получать электронные сообщения о новых продуктах, услугах и предложениях.';
$lang['Signup.index.field_confirmpassword'] = 'Подтвердите пароль';
$lang['Signup.index.field_newpassword'] = 'Пароль';
$lang['Signup.index.field_password'] = 'Пароль';
$lang['Signup.index.field_username'] = 'Имя пользователя';
$lang['Signup.index.field_action_signup'] = 'Создать учетную запись';
$lang['Signup.index.field_action_login'] = 'Войти';
$lang['Signup.index.field_action_continue'] = 'Продолжить как %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Укажите имя пользователя';
$lang['Signup.index.field_username_type_email'] = 'Используйте электронную почту в качестве имени пользователя';
$lang['Signup.index.field_email'] = 'Электронная почта';
$lang['Signup.index.field_fax'] = 'Факс';
$lang['Signup.index.field_phone'] = 'Телефон';
$lang['Signup.index.field_title'] = 'Название';
$lang['Signup.index.field_country'] = 'Страна';
$lang['Signup.index.field_zip'] = 'Почтовый индекс';
$lang['Signup.index.field_state'] = 'Штат/провинция';
$lang['Signup.index.field_city'] = 'Город';
$lang['Signup.index.field_address2'] = 'Адрес 2';
$lang['Signup.index.field_address1'] = 'Адрес 1';
$lang['Signup.index.field_company'] = 'Компания/организация.';
$lang['Signup.index.field_lastname'] = 'Фамилия';
$lang['Signup.index.field_firstname'] = 'Имя';
$lang['Signup.index.field_taxid'] = 'ИНН/ВАТИН';
$lang['Signup.!notice.email_verification'] = 'Было отправлено сообщение для проверки вашего адреса электронной почты. Пожалуйста, завершите проверку при первой же возможности.';
$lang['Signup.!notice.force_email_usernames'] = 'Ваше имя пользователя будет совпадать с вашим адресом электронной почты.';
$lang['Signup.!error.not_client_owner'] = 'Чтобы продолжить, вы должны войти в систему как владелец клиента.';
$lang['Signup.!error.captcha.invalid'] = 'Введенная капча недействительна. Пожалуйста, попробуйте еще раз.';
$lang['Signup.otp.field_submit'] = 'Войти';
$lang['Signup.otp.field_otp'] = 'Одноразовый пароль';
$lang['Signup.otp.login_heading'] = 'Войти';
$lang['Signup.index.field_agree_tos'] = 'Я прочитал и согласен с <a href="%1$s" target="_blank">Положениями и условиями</a>';
$lang['Signup.otp.description'] = 'Пожалуйста, введите ваш одноразовый пароль.';
$lang['Signup.otp.page_title'] = 'Войти';
$lang['Signup.!error.invalid_agree_tos'] = 'Вы должны подтвердить свое согласие с условиями и положениями.';
